Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/owncloud/client.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChristian Kamm <mail@ckamm.de>2018-01-26 11:27:06 +0300
committerChristian Kamm <mail@ckamm.de>2018-04-18 11:27:51 +0300
commit8358dabbfd4b88f6fbb339186ca02936ec903456 (patch)
tree833414a75545805e96138bb760fbfcaea36cbbc7 /src/gui/folderman.h
parent8b6ae04155fe0f0877ed977a4227cd28715311b5 (diff)
Folder: Simplify relative path computation
It was done manually in several places after folderForPath() calls.
Diffstat (limited to 'src/gui/folderman.h')
-rw-r--r--src/gui/folderman.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/gui/folderman.h b/src/gui/folderman.h
index 3eb6024e2..ae9c48f89 100644
--- a/src/gui/folderman.h
+++ b/src/gui/folderman.h
@@ -77,8 +77,13 @@ public:
/** Removes a folder */
void removeFolder(Folder *);
- /** Returns the folder which the file or directory stored in path is in */
- Folder *folderForPath(const QString &path);
+ /**
+ * Returns the folder which the file or directory stored in path is in
+ *
+ * Optionally, the path relative to the found folder is returned in
+ * relativePath.
+ */
+ Folder *folderForPath(const QString &path, QString *relativePath = nullptr);
/**
* returns a list of local files that exist on the local harddisk for an